# Contributing to MCP Community

First of all, thank you for you interest in contributing to MCP Community! We're so glad to have you here.

We are currently working on our contribution guide. Stay tuned for more details.

In the meantime, these are the best ways to contribute to MCP Community:

- Ask questions and help others in our [community](https://join.slack.com/t/mirascope-community/shared_invite/zt-2ilqhvmki-FB6LWluInUCkkjYD3oSjNA)!
- Create and/or comment on [GitHub Issues](https://github.com/Mirascope/mcp-community/issues).
- Open/Submit a [Pull Request](https://github.com/Mirascope/mcp-community/pulls) through GitHub.

In our own experience, we've found the best way to get started contributing to a library is through updates to our documentation. Such updates not only require understanding what MCP Community can do today but also helps to discover areas where we are lacking.

You can submit updates through PRs against the [documentation source code](https://github.com/Mirascope/mcp-community/tree/main/docs).